# Welcome to BlocksNet documentation!

```{include} ../../README.md
:start-after: <!-- logo-start -->
:end-before: <!-- logo-end -->
```

```{include} ../../README.md
:start-after: <!-- description-start -->
:end-before: <!-- description-end -->
```

## Documentation:

```{toctree}
:maxdepth: 2

blocksnet/index
get_started/index
examples/index
api/index
about_us
```

```{include} ../../README.md
:start-after: <!-- features-start -->
:end-before: <!-- features-end -->
```

```{include} ../../README.md
:start-after: <!-- acknowledgments-start -->
:end-before: <!-- acknowledgments-end -->
```
